==> improved-maps-0.4.3%2Bmc1.21.5-sources.jar: com/craftycorvid/improvedmaps/ImprovedMapsModifyVanillaItems.java <==
package com.craftycorvid.improvedmaps;

import java.util.List;
import net.minecraft.class_124;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1806;
import net.minecraft.class_1937;
import net.minecraft.class_22;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_9290;
import net.minecraft.class_9323;
import net.minecraft.class_9334;
import com.google.common.collect.Lists;
import eu.pb4.polymer.core.api.item.PolymerItemUtils;

public final class ImprovedMapsModifyVanillaItems {
    public static void initialize() {
        PolymerItemUtils.ITEM_CHECK.register((itemStack) -> {
            return itemStack.method_31574(class_1802.field_8204);
        });

        PolymerItemUtils.ITEM_MODIFICATION_EVENT.register((original, client, context) -> {
            // Add extra tooltip lines to filled maps
            if (original.method_31574(class_1802.field_8204)) {
                class_1799 out = original.method_7972();
                List<class_2561> loreTexts = Lists.newArrayList();
                if (context.getPlayer() == null) {
                    return client;
                }
                class_1937 world = context.getPlayer().method_37908();
                class_22 mapState = class_1806.method_8001(out, world);

                if (mapState != null) {
                    loreTexts.add(class_2561
                            .method_43470("Dimension " + ImprovedMapsUtils.formatDimensionString(
                                    mapState.field_118.method_29177().toString()))
                            .method_10862(class_2583.field_24360.method_10978(false).method_10977(class_124.field_1080)));
                    loreTexts.add(class_2561
                            .method_43470("Center " + mapState.field_116 + ", " + mapState.field_115)
                            .method_10862(class_2583.field_24360.method_10978(false).method_10977(class_124.field_1080)));
                    loreTexts.add(class_2561
                            .method_43470("Scale "
                                    + ImprovedMapsUtils.scaleToString((int) mapState.field_119))
                            .method_10862(class_2583.field_24360.method_10978(false).method_10977(class_124.field_1080)));

                    var loreComponent = new class_9290(loreTexts);
                    out.method_57365(class_9323.method_57827()
                            .method_57840(class_9334.field_49632, loreComponent).method_57838());

                    return out;
                }
            }
            return client;
        });
    }

}

==> improved-maps-0.4.4%2Bmc1.21.9-sources.jar: com/craftycorvid/improvedmaps/ImprovedMapsModifyVanillaItems.java <==
package com.craftycorvid.improvedmaps;

import java.util.List;
import net.minecraft.class_124;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1806;
import net.minecraft.class_22;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_3218;
import net.minecraft.class_9290;
import net.minecraft.class_9323;
import net.minecraft.class_9334;
import com.google.common.collect.Lists;
import eu.pb4.polymer.core.api.item.PolymerItemUtils;

public final class ImprovedMapsModifyVanillaItems {
    public static void initialize() {
        PolymerItemUtils.CONTEXT_ITEM_CHECK.register((itemStack, context) -> {
            return itemStack.method_31574(class_1802.field_8204);
        });

        PolymerItemUtils.ITEM_MODIFICATION_EVENT.register((original, client, context) -> {
            // Add extra tooltip lines to filled maps
            if (original.method_31574(class_1802.field_8204)) {
                class_1799 out = original.method_7972();
                List<class_2561> loreTexts = Lists.newArrayList();
                if (context.getPlayer() == null) {
                    return client;
                }
                class_3218 world = context.getPlayer().method_51469();
                class_22 mapState = class_1806.method_8001(out, world);

                if (mapState != null) {
                    loreTexts.add(class_2561
                            .method_43470("Dimension " + ImprovedMapsUtils.formatDimensionString(
                                    mapState.field_118.method_29177().toString()))
                            .method_10862(class_2583.field_24360.method_10978(false).method_10977(class_124.field_1080)));
                    loreTexts.add(class_2561
                            .method_43470("Center " + mapState.field_116 + ", " + mapState.field_115)
                            .method_10862(class_2583.field_24360.method_10978(false).method_10977(class_124.field_1080)));
                    loreTexts.add(class_2561
                            .method_43470("Scale "
                                    + ImprovedMapsUtils.scaleToString((int) mapState.field_119))
                            .method_10862(class_2583.field_24360.method_10978(false).method_10977(class_124.field_1080)));

                    var loreComponent = new class_9290(loreTexts);
                    out.method_57365(class_9323.method_57827()
                            .method_57840(class_9334.field_49632, loreComponent).method_57838());

                    return out;
                }
            }
            return client;
        });
    }

}
